tifa
---
![](https://img.shields.io/badge/LICENSE-MIT-blue.svg)

a modern flask scaffolding

![](https://storage.googleapis.com/duan/etc/A45A991C-54C7-4B6A-8906-9265CE7893E8/tifa.jpg)


## Install

```
$ pip install tifa
```

## Usage

### Generate a tifa configuration file

```
$ tifa init
```

### Initialize project through configuration

```
$ tifa gen
```

This command would read `tifa.yaml` by default. To use a specific config file: 

```
$ tifa gen --config path/to/config.yaml
```
